Python Documentation
====================

.. toctree::
   :hidden:

   other

Sphinx is a *wierd* tool. This is a demo to see 

| what can
| we do?

.. _my-note:
.. warning::
   This is a WIP demo!


See :ref:`this note <my-note>` for a disclaimer.

I also want to show you the figure (see :numref:`mountain`) in :doc:`other`.
